@@ -6,7 +6,8 @@
 #'@param y The target variable
 #'@param xeq The variables to be used in the equilibrium term of the error correction model
 #'@param xtr The variables to be used in the transient term of the error correction model
-#'@param criterion Whether AIC (default), BIC, adjustedR2, or rmse should be used to select variables 
+#'@param includeIntercept Boolean whether the y-intercept should be included
+#'@param criterion Whether AIC (default), BIC, or adjustedR2 should be used to select variables 
 #'@return an lm object representing an error correction model using backwards selection
 #'@details
 #'When inputting a single variable for xeq or xtr, it is important to input it in the format "xeq=df['col1']" in order to retain the data frame class. Inputting such as "xeq=df[,'col1']" or "xeq=df$col1" will result in errors in the ecm function.
@@ -21,14 +22,14 @@
 #'
 #'#Use backwards selection to choose which predictors are needed 
 #'xeq <- xtr <- trn[c('CorpProfits', 'FedFundsRate', 'UnempRate')]
-#'modelback <- ecmback(trn$Wilshire5000, xeq, xtr, criterion = 'AIC')
+#'modelback <- ecmback(trn$Wilshire5000, xeq, xtr, includeIntercept=TRUE, criterion = 'AIC')
 #'print(modelback)
 #'#Backwards selection chose CorpProfits in the equilibrium term, 
 #'#CorpProfits and UnempRate in the transient term.
 #'
 #'@export
 #'@importFrom stats lm complete.cases step
-ecmback <- function (y, xeq, xtr, criterion = "AIC") {
+ecmback <- function (y, xeq, xtr, includeIntercept = T, criterion = "AIC") {
   if (sum(grepl("^delta|Lag1$", names(xtr))) > 0 | sum(grepl("^delta|Lag1$", names(xeq))) > 0) {
     warning("You have column name(s) in xeq or xtr that begin with 'delta' or end with 'Lag1'. It is strongly recommended that you change this, otherwise the function 'ecmpredict' will result in errors or incorrect predictions.")
   }
@@ -48,7 +49,11 @@ ecmback <- function (y, xeq, xtr, criterion = "AIC") {
   x <- cbind(xtr, xeq[complete.cases(xeq), ])
   x <- cbind(x, yLag1)
   names(x) <- c(xtrnames, xeqnames, "yLag1")
-  full <- lm(dy ~ ., data = x)
+  if (includeIntercept){
+    full <- lm(dy ~ ., data = x)
+  } else {
+    full <- lm(dy ~ .-1, data = x)
+  }
   null <- lm(dy ~ yLag1, data = x)
   if (criterion == "AIC" | criterion == "BIC") {
     if (criterion == "AIC") {
@@ -68,32 +73,24 @@ ecmback <- function (y, xeq, xtr, criterion = "AIC") {
       if (partialAdjR2 >= fullAdjR2) {
         x <- newx
         ecm <- partial
-        full <- lm(dy ~ ., data = x)
+        if (includeIntercept){
+          full <- lm(dy ~ ., data = x)
+        } else {
+          full <- lm(dy ~ .-1, data = x)
+        }
       } else {
-        ecm <- lm(dy ~ ., data = x)
+        if (includeIntercept){
+          ecm <- lm(dy ~ ., data = x)
+        } else {
+          ecm <- lm(dy ~ .-1, data = x)
+        }
       }
     }
-  } else if (criterion == "rmse"){
-    fullrmse <- partialrmse <- sqrt(mean(full$residuals^2))
-    while (partialrmse <= fullrmse) {
-      fullrmse <- sqrt(mean(full$residuals^2))
-      todrop <- which.max(summary(full)$coef[-1, 4])
-      newx <- x[which(!names(x) %in% names(todrop))]
-      partial <- lm(dy ~ ., data = newx)
-      partialrmse <- sqrt(mean(partial$residuals^2))
-      if (partialrmse <= fullrmse) {
-        x <- newx
-        ecm <- partial
-        full <- lm(dy ~ ., data = x)
-      } else {
-        ecm <- lm(dy ~ ., data = x)
-      }
-    }
-  }
+  } 
   if (sum(grepl("^delta", names(ecm$coefficients))) == 0) {
-    warning("Backwards selection has opted to leave out all transient terms from the final model. This means you essentially have a first order differenced autoregressive model, not an error correction model.")
+    warning("Backwards selection has opted to leave out all transient terms from the final model. This means you have a first order differenced autoregressive model of sorts, not a full error correction model.")
   } else if (sum(grepl("Lag1$", names(ecm$coefficients))) == 0) {
-    warning("Backwards selection has opted to leave out all equilibrium terms from the final model. This means you essentially have a first order differenced autoregressive model with the x terms also differenced, not an error correction model.")
+    warning("Backwards selection has opted to leave out all equilibrium terms from the final model. This means you have a first order differenced autoregressive model of sorts, not a full error correction model.")
   }
   return(ecm)
 }
\ No newline at end of file
